summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
author Eric Hameleers <alien@slackware.com>2016-05-29 20:27:20 +0200
committer Eric Hameleers <alien@slackware.com>2016-05-29 20:27:20 +0200
commit6fd789cce0e6fa088ef3b31530e1035f55747dad (patch)
tree7b16bfe1f5e5ad12a063745ada2b055df291b13f
parentb4ba412607f5a9958b90acdae9cb6faf495bfe72 (diff)
downloadliveslak-6fd789cce0e6fa088ef3b31530e1035f55747dad.tar.gz
liveslak-6fd789cce0e6fa088ef3b31530e1035f55747dad.tar.xz
XFCE: do not copy optional/ or addons/ content into the XFCE ISO.
We need to maintain strict size requirements to keep the maximum size of the XFCE ISO below 737.280.000 bytes (703 MB) so that it fits on CDROM. You can always add optional/addons modules later if you create a USB Live medium out of the ISO.
-rwxr-xr-xmake_slackware_live.sh19
1 files changed, 11 insertions, 8 deletions
diff --git a/make_slackware_live.sh b/make_slackware_live.sh
index 9f8371d..89b2217 100755
--- a/make_slackware_live.sh
+++ b/make_slackware_live.sh
@@ -1853,14 +1853,17 @@ else
ISOTAG="-$(echo $LIVEDE |tr A-Z a-z)"
fi
-# Copy our stockpile of add-on modules into place:
-if ls ${LIVE_TOOLDIR}/addons/*.sxz 1>/dev/null 2>&1 ; then
- cp ${LIVE_TOOLDIR}/addons/*.sxz ${LIVE_MOD_ADD}/
-fi
-
-# If we have optionals, copy those too:
-if ls ${LIVE_TOOLDIR}/optional/*.sxz 1>/dev/null 2>&1 ; then
- cp ${LIVE_TOOLDIR}/optional/*.sxz ${LIVE_MOD_OPT}/
+# We keep strict size requirements for the XFCE ISO:
+# addons/optional modules will not be added.
+if [ "$LIVEDE" != "XFCE" ]; then
+ # Copy our stockpile of add-on modules into place:
+ if ls ${LIVE_TOOLDIR}/addons/*.sxz 1>/dev/null 2>&1 ; then
+ cp ${LIVE_TOOLDIR}/addons/*.sxz ${LIVE_MOD_ADD}/
+ fi
+ # If we have optionals, copy those too:
+ if ls ${LIVE_TOOLDIR}/optional/*.sxz 1>/dev/null 2>&1 ; then
+ cp ${LIVE_TOOLDIR}/optional/*.sxz ${LIVE_MOD_OPT}/
+ fi
fi
if [ "$LIVEDE" != "XFCE" -a "$LIVEDE" != "SLACKWARE" ]; then